@@ -261,15 +261,21 @@ class Handler(tornado.web.RequestHandler):
         self.write("<table border=1 cellpadding=5>")
         self.write("<tr><th>Status</th><th>Commit</th><th>Author</th><th>Completed</th><th>Duration</th></tr>")
         for push in self.application.db.all("SELECT * FROM push ORDER BY created DESC LIMIT 25"):
-            started = datetime.datetime.strptime(push["started"], "%Y-%m-%d %H:%M:%S")
+            if push["started"]:
+                started = datetime.datetime.strptime(push["started"], "%Y-%m-%d %H:%M:%S")
+            else:
+                started = None
             if push["completed"]:
                 completed = datetime.datetime.strptime(push["completed"], "%Y-%m-%d %H:%M:%S")
             else:
                 completed = None
 
-            self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>" %
-                       (push["status"], push["commit"], push["author"],
-                        completed, (completed - started).seconds) if completed else "waiting")
+            if started and completed:
+                self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>" %
+                           (push["status"], push["commit"], push["author"], completed, (completed - started).seconds))
+            else:
+                self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td colspan=2>waitinh</td></tr>" %
+                           (push["status"], push["commit"], push["author"]))
         self.write("</table>")
 
     def json(self, obj, status=None):
